[tor-commits] [trunnel/master] Documentation and markdown syntax fixes

2014-10-02 Thread nickm
commit f9f971d73572e705dfa067b98c8008577dee567e
Author: Nick Mathewson ni...@torproject.org
Date:   Thu Oct 2 09:05:24 2014 -0400

Documentation and markdown syntax fixes
---
 .gitignore |2 ++
 MANIFEST.in|1 +
 README |3 +++
 doc/Makefile   |8 
 doc/trunnel.md |   22 --
 5 files changed, 26 insertions(+), 10 deletions(-)

diff --git a/.gitignore b/.gitignore
index 0efb950..16839b2 100644
--- a/.gitignore
+++ b/.gitignore
@@ -21,6 +21,8 @@ tests.log
 
 /doc/*.[ch]
 /doc/trunnel.html
+/doc/trunnel-manual.html
+/doc/trunnel-manual.html.tmp
 /doc/trunnel.txt
 /examples/*.[ch]
 /test/grammar.tmp
diff --git a/MANIFEST.in b/MANIFEST.in
index 2eb978a..3f51dc5 100644
--- a/MANIFEST.in
+++ b/MANIFEST.in
@@ -6,6 +6,7 @@ include examples/*.trunnel
 
 include doc/*.md
 include doc/GRAMMAR
+include doc/Makefile
 
 include test/failing/*.trunnel
 include test/valid/*.trunnel
diff --git a/README b/README
index 8610a8e..743ff37 100644
--- a/README
+++ b/README
@@ -1,6 +1,9 @@
 a trunnel is a primitive nail
 =
 
+And trunnel is a tool that converts representations of simple data
+formats into C code that can parse and encode those formats.
+
 The official git repository is browseable at
https://gitweb.torproject.org/trunnel.git
 
diff --git a/doc/Makefile b/doc/Makefile
new file mode 100644
index 000..bb8bfc9
--- /dev/null
+++ b/doc/Makefile
@@ -0,0 +1,8 @@
+
+all: trunnel-manual.html
+
+trunnel-manual.html: trunnel.md
+   markdown trunnel.md  trunnel-manual.html.tmp  mv 
trunnel-manual.html.tmp trunnel-manual.html
+
+clean:
+   rm -f trunnel-manual.html trunnel-manual.html.tmp
diff --git a/doc/trunnel.md b/doc/trunnel.md
index 23021af..2ffbab8 100644
--- a/doc/trunnel.md
+++ b/doc/trunnel.md
@@ -40,7 +40,9 @@ Here are some non-goals for Trunnel:
* Run as fast as possible.
* Support very old versions of Python with the code generator.
* Support pre-ANSI C with the code generator.
-
+   * Generate optimal code
+   * Generate code with no redundant checks
+   * Handle input incrementally
 
 ## 1. About this document
 
@@ -227,7 +229,7 @@ members the specified number of times.  Strings are not 
expected to be
 NUL-terminated in the binary format.
 
 Fixed-length arrays of integers are represented as arrays of the appropriate
-uint*_t type. Fixed-length arrays of structures are represented as arrays of
+uint\*_t type. Fixed-length arrays of structures are represented as arrays of
 pointers to that structure type.  Fixed-length arrays of char are represented
 as having one extra byte at the end, so that we can ensure that the C
 representation of the array always ends with NUL -- internal NULs are
@@ -342,7 +344,7 @@ When encoding a union of this kind, you do _not_ need to 
set the 'length'
 field; trunnel will fill it in for you in the output automatically based on
 the actual length.
 
-(*In a future version of Trunnel, length constraints might be supported
+(*In a future version of Trunnel*, length constraints might be supported
 independently of unions; the code is orthogonal internally.)
 
 ### Structure variants: end-of-string constraints
@@ -357,7 +359,7 @@ for a given structure, you can give an end-of-string 
constraint:
eos;
 }
 
-(*This feature might go away in a future version if it doesn't turn
+(*This feature might go away* in a future version if it doesn't turn
 out to be useful.)
 
 ### Fields that extend up to a certain point before the end of the structure
@@ -384,8 +386,8 @@ You can also use this notation to indicate the extent of a 
union:
u8 type;
union u[type] with length ..-32 {
   1: u8 bytes[];
- 2: u8 salt[16];
-u8 other_bytes[];
+  2: u8 salt[16];
+ u8 other_bytes[];
}
u64 data[4];
 }
@@ -410,7 +412,7 @@ To support this, trunnel provides context-dependent objects:
u8 iv[stream_settings.iv_len];
union msg[stream_settings.block_mode] {
   0: u16 n_bytes; u8 bytes[n_bytes];
- 1: u16 n_blocks; struct block[n_blocks];
+  1: u16 n_blocks; struct block[n_blocks];
};
u8 mac[stream_settings.maclen];
 }
@@ -490,7 +492,7 @@ objects inside it.  It's okay to call it with NULL.
 
 If you have a filled-in object, you can encode it into a buffer:
 
-   ssize_t example_encode(uint8_t *buf, size_t buf_len, const example_t *obj);
+ ssize_t example_encode(uint8_t *buf, size_t buf_len, const example_t 
*obj);
 
 The `buf_len` parameter describes the number of available bytes in `buf` to
 use for encoding `obj`.  On success, this function will return the number of
@@ -500,7 +502,7 @@ return -1 if there is an error that prevents encoding the 
object entirely.
 
 You can find out the required buffer length before the encoding, if you like:
 
-   ssize_t example_encoded_len(const example_t *obj);
+ ssize_t example_encoded_len(const example_t *obj);

[tor-commits] [trunnel/master] Fix a code wart spotted by Gunes Acar

2014-10-02 Thread nickm
commit 54d056ca38f1a34e08633debd4dfb386d022525e
Author: Nick Mathewson ni...@torproject.org
Date:   Thu Oct 2 09:31:34 2014 -0400

Fix a code wart spotted by Gunes Acar
---
 lib/trunnel/Grammar.py |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/lib/trunnel/Grammar.py b/lib/trunnel/Grammar.py
index d943868..fa30b72 100644
--- a/lib/trunnel/Grammar.py
+++ b/lib/trunnel/Grammar.py
@@ -983,7 +983,7 @@ class Parser(trunnel.spark.GenericParser, object):
 return info[0]
 
 def p_ContextDecl(self, info):
- ContextDecl ::= context ID { ContextMembers }
+ ContextDecl ::= context ID { ContextMembers } 
 return StructDecl(str(info[1]), info[3], isContext=True)
 
 def p_ContextMembers_1(self, info):

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 7f9d47b1935fbad59519db79c73e9885f416ec45
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 13:45:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |   19 ++-
 1 file changed, 10 insertions(+), 9 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index fba63b7..b44791b 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -4,14 +4,15 @@
 # 
 # Translators:
 # identity, 2012
+# Rico Chan r...@tutanota.de, 2014
 # trio t...@esperanto.org, 2011
 msgid 
 msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-07-26 09:42+\n
-Last-Translator: runasand runa.sand...@gmail.com\n
+PO-Revision-Date: 2014-10-02 13:42+\n
+Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
 Content-Type: text/plain; charset=UTF-8\n
@@ -33,7 +34,7 @@ msgstr 
 #. Tor Browser
 #: lib/bridgedb/HTTPServer.py:121
 msgid Sorry! Something went wrong with your request.
-msgstr 
+msgstr Pardonu! Io ne funkcias pri via peto.
 
 #: lib/bridgedb/strings.py:18
 msgid [This is an automated message; please do not reply.]
@@ -41,34 +42,34 @@ msgstr [Ĉi tiu estas aŭtomate kreita mesaĝo; bonvole ne 
respondu.]
 
 #: lib/bridgedb/strings.py:20
 msgid Here are your bridges:
-msgstr 
+msgstr Jen viaj pontoj/bridges.
 
 #: lib/bridgedb/strings.py:22
 #, python-format
 msgid 
 You have exceeded the rate limit. Please slow down! The minimum time 
between\n
 emails is %s hours. All further emails during this time period will be 
ignored.
-msgstr 
+msgstr Vi superis la limiton. Bonvolu malakceli! La minimala tempo inter 
retleteroj estas\n%s horoj. Pliaj retiloj dum tiu tempo estos ignorata.
 
 #: lib/bridgedb/strings.py:25
 msgid 
 COMMANDs: (combine COMMANDs to specify multiple options simultaneously)
-msgstr 
+msgstr ORDONOJ: (kombinu ORDONOJ por samtempe specifiki diversaj opcioj).
 
 #. TRANSLATORS: Please DO NOT translate the word BridgeDB.
 #: lib/bridgedb/strings.py:28
 msgid Welcome to BridgeDB!
-msgstr 
+msgstr Estu bonvena al BridgeDB!
 
 #. TRANSLATORS: Please DO NOT translate the words transport or TYPE.
 #: lib/bridgedb/strings.py:30
 msgid Currently supported transport TYPEs:
-msgstr 
+msgstr Nuntempe subtenata transport TYPEs:
 
 #: lib/bridgedb/strings.py:31
 #, python-format
 msgid Hey, %s!
-msgstr 
+msgstr Saluton, %s!
 
 #: lib/bridgedb/strings.py:32
 msgid Hello, friend!

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [trunnel/master] Re-run autopep8

2014-10-02 Thread nickm
commit 18d475d19998a223f48fae46279f57dca05e6af9
Author: Nick Mathewson ni...@torproject.org
Date:   Thu Oct 2 09:42:03 2014 -0400

Re-run autopep8
---
 lib/trunnel/Boilerplate.py |   10 +++--
 lib/trunnel/CodeGen.py |  102 +++-
 lib/trunnel/Grammar.py |   14 --
 lib/trunnel/__init__.py|1 -
 lib/trunnel/__main__.py|6 +--
 setup.py   |2 +-
 6 files changed, 82 insertions(+), 53 deletions(-)

diff --git a/lib/trunnel/Boilerplate.py b/lib/trunnel/Boilerplate.py
index 0fc20eb..f7a5d8e 100644
--- a/lib/trunnel/Boilerplate.py
+++ b/lib/trunnel/Boilerplate.py
@@ -6,7 +6,8 @@
 import os
 import trunnel
 
-FILES = [ trunnel.c, trunnel.h, trunnel-impl.h ]
+FILES = [trunnel.c, trunnel.h, trunnel-impl.h]
+
 
 def emit(target_dir=None):
 if target_dir == None:
@@ -19,11 +20,12 @@ def emit(target_dir=None):
  os.path.join(directory, data, f),
  os.path.join(target_dir, f))
 
+
 def emitfile(fname, in_fname, out_fname):
 settings = {
-'fname' : fname,
-'version' : trunnel.__version__
-}
+'fname': fname,
+'version': trunnel.__version__
+}
 with open(in_fname, 'r') as inp, open(out_fname, 'w') as out:
 out.write(/* %(fname)s -- copied from Trunnel v%(version)s\n
* https://gitweb.torproject.org/trunnel.git\n;
diff --git a/lib/trunnel/CodeGen.py b/lib/trunnel/CodeGen.py
index 9b07e2f..5867fd0 100644
--- a/lib/trunnel/CodeGen.py
+++ b/lib/trunnel/CodeGen.py
@@ -163,12 +163,12 @@ class Checker(ASTVisitor):
 self.structNames = set()
 self.constNames = set()
 self.constValues = {}
-self.contextNames = set() #
+self.contextNames = set()  # 
 self.structFieldNames = None
 self.structIntFieldNames = None
 self.structIntFieldUsage = None
 self.structUses = {}
-self.structUsesContexts = {} #
+self.structUsesContexts = {}  # 
 self.memberPrefix = 
 self.sortedStructs = None
 self.lenFieldDepth = 0
@@ -227,9 +227,11 @@ class Checker(ASTVisitor):
 # check for context mismatch.
 for structname, uses in self.structUses.items():
 for u in uses:
-missing = self.structUsesContexts[u] - 
self.structUsesContexts[structname]
+missing = self.structUsesContexts[
+u] - self.structUsesContexts[structname]
 if missing:
-raise CheckError({0} contains {1}, which uses contexts 
({2}), but {0} does not use those contexts..format(structname, u, 
,.join(missing)))
+raise CheckError(
+{0} contains {1}, which uses contexts ({2}), but {0} 
does not use those contexts..format(structname, u, ,.join(missing)))
 
 # Perform a topological sort.
 sorted_structs = []
@@ -251,7 +253,7 @@ class Checker(ASTVisitor):
 externNames = set(es.name for es in f.externStructs)
 
 self.sortedStructs = [
-s for s in sorted_structs if s not in externNames ]
+s for s in sorted_structs if s not in externNames]
 
 def visitConstDecl(self, cd):
 self.constValues[cd.name] = cd.value.value
@@ -338,7 +340,8 @@ class Checker(ASTVisitor):
 
 def visitSMLenConstrained(self, sml):
 if sml.lengthfield != None:
-self.checkIntField(sml.lengthfield, union length, 
self.structName)
+self.checkIntField(
+sml.lengthfield, union length, self.structName)
 self.lenFieldDepth += 1
 if self.lenFieldDepth = 2:
 # This is an undesirable restriction, but the alternative
@@ -358,9 +361,10 @@ class Checker(ASTVisitor):
 self.unionName = smu.name
 self.unionMatching = []
 if '.' in smu.tagfield:
-self.unionTagMax = (164)-1  # wrong
+self.unionTagMax = (1  64) - 1  #  wrong
 else:
-self.unionTagMax = 
TYPE_MAXIMA[self.structIntFieldNames[smu.tagfield]]
+self.unionTagMax = TYPE_MAXIMA[
+self.structIntFieldNames[smu.tagfield]]
 self.containing = %s.%s % (self.structName, smu.name)
 self.memberPrefix = smu.name + _
 self.foundDefaults = 0
@@ -445,7 +449,7 @@ class Checker(ASTVisitor):
 def checkIntField(self, fieldname, ftype, inside):
 Check whether a reference to an integer field is correct.
 if '.' in fieldname:
-ctx,field = fieldname.split('.', 2)
+ctx, field = fieldname.split('.', 2)
 if ctx not in self.contextNames:
 raise CheckError(Unrecognized context %s for %s in %s % (
 fieldname.context, ftype, inside))
@@ -555,7 +559,6 @@ class Annotator(ASTVisitor):
 if sml.lengthfield is None:
 self.after_leftover_field = True
 
-
 def 

[tor-commits] [trunnel/master] Change spark's interface to use function decorators

2014-10-02 Thread nickm
commit 112fd73cb6abf0ad5fcbfb1304d530793fda6ed2
Author: Nick Mathewson ni...@torproject.org
Date:   Thu Oct 2 10:00:21 2014 -0400

Change spark's interface to use function decorators

Back when spark was new, sticking patterns and productions in
docstrings was kinda reasonable.  But now that we have function
decorators in Python, I should use them: doing so will let me
actually put documentation on the methods of the lexer and parser.
---
 lib/trunnel/Grammar.py |  209 +---
 lib/trunnel/spark.py   |   25 +-
 2 files changed, 131 insertions(+), 103 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index b44791b..f65b813 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 13:42+\n
+PO-Revision-Date: 2014-10-02 14:12+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -54,7 +54,7 @@ msgstr Vi superis la limiton. Bonvolu malakceli! La minimala 
tempo inter retlet
 #: lib/bridgedb/strings.py:25
 msgid 
 COMMANDs: (combine COMMANDs to specify multiple options simultaneously)
-msgstr ORDONOJ: (kombinu ORDONOJ por samtempe specifiki diversaj opcioj).
+msgstr ORDONOJ: (kombinu ORDONOJN por samtempe specifiki diversaj opciojn).
 
 #. TRANSLATORS: Please DO NOT translate the word BridgeDB.
 #: lib/bridgedb/strings.py:28
@@ -73,11 +73,11 @@ msgstr Saluton, %s!
 
 #: lib/bridgedb/strings.py:32
 msgid Hello, friend!
-msgstr 
+msgstr Saluton, amiko!
 
 #: lib/bridgedb/strings.py:33 lib/bridgedb/templates/base.html:101
 msgid Public Keys
-msgstr 
+msgstr publikaj ŝlosiloj
 
 #. TRANSLATORS: This string will end up saying something like:
 #. This email was generated with rainbows, unicorns, and sparkles
@@ -87,7 +87,7 @@ msgstr 
 msgid 
 This email was generated with rainbows, unicorns, and sparkles\n
 for %s on %s at %s.
-msgstr 
+msgstr Ĉi tiu retletero estas generita kun ĉielarkoj, unikornoj kaj 
steloj\npor %s je %s, %s.
 
 #. TRANSLATORS: Please DO NOT translate BridgeDB.
 #. TRANSLATORS: Please DO NOT translate Pluggable Transports.
@@ -101,7 +101,7 @@ msgid 
 difficult for anyone watching your internet traffic to determine that you 
are\n
 using Tor.\n
 \n
-msgstr 
+msgstr BridgeDB povas provizi pontojn/bridges kun diversaj %stypes de 
Pluggable Transports%s,\nkiuj povas helpi sekretigi viajn konektojn al la Tor 
Network kaj malfaciligi provojn kiuj estas destinitaj\nobservi vian 
datumtrafikon kaj vian uzantecon de Tor.\n
 
 #. TRANSLATORS: Please DO NOT translate Pluggable Transports.
 #: lib/bridgedb/strings.py:54

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 83e0b1fde5073bc198b36cc9e91af4b465879679
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 14:45:02 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |   20 ++--
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index f65b813..1945092 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 14:12+\n
+PO-Revision-Date: 2014-10-02 14:40+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -42,7 +42,7 @@ msgstr [Ĉi tiu estas aŭtomate kreita mesaĝo; bonvole ne 
respondu.]
 
 #: lib/bridgedb/strings.py:20
 msgid Here are your bridges:
-msgstr Jen viaj pontoj/bridges.
+msgstr Jen viaj retpontoj.
 
 #: lib/bridgedb/strings.py:22
 #, python-format
@@ -109,7 +109,7 @@ msgid 
 Some bridges with IPv6 addresses are also available, though some Pluggable\n
 Transports aren't IPv6 compatible.\n
 \n
-msgstr 
+msgstr AnkaÅ­ kelkaj retpontoj kun IPv6-adresoj estas disponeblaj, sed iuj 
Pluggable\nTransports ne estas IPv6-kongrua.\n
 
 #. TRANSLATORS: Please DO NOT translate BridgeDB.
 #. TRANSLATORS: The phrase plain-ol'-vanilla means plain, boring,
@@ -123,20 +123,20 @@ msgid 
 Pluggable Transports %s which maybe doesn't sound as cool, but they can 
still\n
 help to circumvent internet censorship in many cases.\n
 \n
-msgstr 
+msgstr Krome BridgeDB havas abundon da regulaj retpontoj %s sen 
iuj\nPluggable Transports %s, kiuj eble ne estas mojosa, tamen ofte povas helpi 
eviti\nreta cenzuro.\n
 
 #: lib/bridgedb/strings.py:76
 msgid What are bridges?
-msgstr 
+msgstr Kio estas retpontoj?
 
 #: lib/bridgedb/strings.py:77
 #, python-format
 msgid %s Bridges %s are Tor relays that help you circumvent censorship.
-msgstr 
+msgstr %s retpontoj %s estas interretaj babiloj kiuj helpas vin eviti 
cenzuro.
 
 #: lib/bridgedb/strings.py:82
 msgid I need an alternative way of getting bridges!
-msgstr 
+msgstr Mi bezonas alternativon ekhavi retpontojn!
 
 #: lib/bridgedb/strings.py:83
 #, python-format
@@ -144,17 +144,17 @@ msgid 
 Another way to get bridges is to send an email to %s. Please note that you 
must\n
 send the email using an address from one of the following email providers:\n
 %s, %s or %s.
-msgstr 
+msgstr Sendu retletero al %s por ekhavi retpontojn alternative. Bonvolu 
konstati ke vi\nbezonas sendi retleteron per adreso de la sekvonta retpoŝta 
provizanto:\n%s, %s aÅ­ %s.
 
 #: lib/bridgedb/strings.py:90
 msgid My bridges don't work! I need help!
-msgstr 
+msgstr Miaj retpontoj ne funkcias! Mi bezonas helpon!
 
 #. TRANSLATORS: Please DO NOT translate Tor.
 #: lib/bridgedb/strings.py:92
 #, python-format
 msgid If your Tor doesn't work, you should email %s.
-msgstr 
+msgstr Se Tor ne funkcias, kontaktigu %s.
 
 #. TRANSLATORS: Please DO NOT translate Pluggable Transports.
 #. TRANSLATORS: Please DO NOT translate Tor Browser.

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 0d5e285ab17211a52655657f2bba81f1afff902c
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 15:15:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |   16 
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index 1945092..faa6300 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 14:40+\n
+PO-Revision-Date: 2014-10-02 15:00+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -164,32 +164,32 @@ msgid 
 Try including as much info about your case as you can, including the list 
of\n
 bridges and Pluggable Transports you tried to use, your Tor Browser 
version,\n
 and any messages which Tor gave out, etc.
-msgstr 
+msgstr Provu klarigi vian kazon tre detale kaj aldonu liston da retpontoj kaj 
Pluggable Transports\nkiujn vi provis uzi. Krome aldonu vian Tor 
Browser-version kaj ĉiujn mesaĝojn, kiujn Tor\neligis.
 
 #: lib/bridgedb/strings.py:103
 msgid Here are your bridge lines:
-msgstr 
+msgstr Jen viaj retpontoj:
 
 #: lib/bridgedb/strings.py:104
 msgid Get Bridges!
-msgstr 
+msgstr Ekhavu retpontojn!
 
 #: lib/bridgedb/strings.py:108
 msgid Please select options for bridge type:
-msgstr 
+msgstr Bonvolu selekti opciojn pri retpontospeco.
 
 #: lib/bridgedb/strings.py:109
 msgid Do you need IPv6 addresses?
-msgstr 
+msgstr Ĉu vi bezonas IPv6-adresojn?
 
 #: lib/bridgedb/strings.py:110
 #, python-format
 msgid Do you need a %s?
-msgstr 
+msgstr Ĉu vi bezonas %s?
 
 #: lib/bridgedb/strings.py:114
 msgid Your browser is not displaying images properly.
-msgstr 
+msgstr Via retumilo vidigas bildojn ne dece.
 
 #: lib/bridgedb/strings.py:115
 msgid Enter the characters from the image above...

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 1a9e67cef463968fb11576ea68c42e7cb9585fcd
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 15:45:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index faa6300..11b5e64 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 15:00+\n
+PO-Revision-Date: 2014-10-02 15:43+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -193,11 +193,11 @@ msgstr Via retumilo vidigas bildojn ne dece.
 
 #: lib/bridgedb/strings.py:115
 msgid Enter the characters from the image above...
-msgstr 
+msgstr Enigu la literoj en la bildo ĉi-supre.
 
 #: lib/bridgedb/strings.py:119
 msgid How to start using your bridges
-msgstr 
+msgstr Kiel komenci uzi viajn retpontojn.
 
 #. TRANSLATORS: Please DO NOT translate Tor Browser.
 #: lib/bridgedb/strings.py:121

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 19739e1ea469081518dc5da56a557be98d03cc34
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 16:15:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index 11b5e64..5c58887 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 15:43+\n
+PO-Revision-Date: 2014-10-02 16:10+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -205,21 +205,21 @@ msgstr Kiel komenci uzi viajn retpontojn.
 msgid 
 To enter bridges into Tor Browser, follow the instructions on the %s Tor\n
 Browser download page %s to start Tor Browser.
-msgstr 
+msgstr Por enigi retpontojn en la Tor Browser, sekvu la lernilon de la 
%s\nTor-Browser-elŝutaĵopaĝo %s por starti la Tor Browser.
 
 #. TRANSLATORS: Please DO NOT translate Tor.
 #: lib/bridgedb/strings.py:125
 msgid 
 When the 'Tor Network Settings' dialogue pops up, click 'Configure' and 
follow\n
 the wizard until it asks:
-msgstr 
+msgstr Kiam la Tor retagordaj dialogujo elklapas, alklaku 'agordi/konfiguri' 
kaj sekvu\nla asistanto ĝis ĝi demandas: 
 
 #. TRANSLATORS: Please DO NOT translate Tor.
 #: lib/bridgedb/strings.py:129
 msgid 
 Does your Internet Service Provider (ISP) block or otherwise censor 
connections\n
 to the Tor network?
-msgstr 
+msgstr Ĉu via provizanto de retservoj (angle: ISP) blokas aŭ alimaniere 
cenzuras konektojn al la Tor-reto?
 
 #. TRANSLATORS: Please DO NOT translate Tor.
 #: lib/bridgedb/strings.py:133

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 7b45d17ac0c25508229cf33d86e8e142155df643
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 16:45:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |   22 +++---
 1 file changed, 11 insertions(+), 11 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index 5c58887..813ba46 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 16:10+\n
+PO-Revision-Date: 2014-10-02 16:43+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -228,49 +228,49 @@ msgid 
 paste the bridge lines into the text input box. Finally, click 'Connect', 
and\n
 you should be good to go! If you experience trouble, try clicking the 
'Help'\n
 button in the 'Tor Network Settings' wizard for further assistance.
-msgstr 
+msgstr Selektu 'Jes' kaj alklaku 'sekva'. Por konfiguri viajn novajn 
retpontojn, kopiu kaj alglui\nla retpontolineojn al la dialogujo. Finfine 
alklaku 'konektiĝi'.\nSe vi havas problemojn, provi alklaki la 'helpo'-butonon 
en la Tor-retagordasistanto\npor pli da asistado.
 
 #: lib/bridgedb/strings.py:141
 msgid Displays this message.
-msgstr 
+msgstr Vidigi ĉi tiun mesaĝon.
 
 #. TRANSLATORS: Please try to make it clear that vanilla here refers to the
 #. same non-Pluggable Transport bridges described above as being
 #. plain-ol'-vanilla bridges.
 #: lib/bridgedb/strings.py:145
 msgid Request vanilla bridges.
-msgstr 
+msgstr Peti regulajn retpontojn (nepermutebla transporta retpontoj / 
non-Pluggable Transport bridges).
 
 #: lib/bridgedb/strings.py:146
 msgid Request IPv6 bridges.
-msgstr 
+msgstr Peti IPv6-retpontojn.
 
 #. TRANSLATORS: Please DO NOT translate the word the word TYPE.
 #: lib/bridgedb/strings.py:148
 msgid Request a Pluggable Transport by TYPE.
-msgstr 
+msgstr Peti permutebla transporto de TYPE.
 
 #. TRANSLATORS: Please DO NOT translate BridgeDB.
 #. TRANSLATORS: Please DO NOT translate GnuPG.
 #: lib/bridgedb/strings.py:151
 msgid Get a copy of BridgeDB's public GnuPG key.
-msgstr 
+msgstr Ekhavi kopio de publika GnuPG-ŝlosilo de BridgeDB.
 
 #: lib/bridgedb/templates/base.html:92
 msgid Report a Bug
-msgstr 
+msgstr raporti cimo
 
 #: lib/bridgedb/templates/base.html:94
 msgid Source Code
-msgstr 
+msgstr fontkodo
 
 #: lib/bridgedb/templates/base.html:97
 msgid Changelog
-msgstr 
+msgstr ŝanĝoprotokolo
 
 #: lib/bridgedb/templates/base.html:99
 msgid Contact
-msgstr 
+msgstr kontakto
 
 #. TRANSLATORS: Please translate this into some silly way to say
 #. There was a problem! in your language. For example,

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/https_everywhere] Update translations for https_everywhere

2014-10-02 Thread translation
commit 0f49a64b9f298912071d10a65a5804d6b9fdff88
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:15:33 2014 +

Update translations for https_everywhere
---
 eo/ssl-observatory.dtd |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/eo/ssl-observatory.dtd b/eo/ssl-observatory.dtd
index 085e2c0..950958c 100644
--- a/eo/ssl-observatory.dtd
+++ b/eo/ssl-observatory.dtd
@@ -1,7 +1,7 @@
 !-- Observatory popup window --
 !ENTITY ssl-observatory.popup.details Details and Privacy Information
 !ENTITY ssl-observatory.popup.later Ask Me Later
-!ENTITY ssl-observatory.popup.no No
+!ENTITY ssl-observatory.popup.no Ne
 
 !ENTITY ssl-observatory.popup.text HTTPS Everywhere can detect attacks
 against your browser by sending the certificates you receive to the

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-greeter] Update translations for tails-greeter

2014-10-02 Thread translation
commit e89ea8bf2bc094113e8c45dd1ee33d424a1e5ff0
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:15:48 2014 +

Update translations for tails-greeter
---
 eo/eo.po |   10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/eo/eo.po b/eo/eo.po
index d075d5f..5abf014 100644
--- a/eo/eo.po
+++ b/eo/eo.po
@@ -7,8 +7,8 @@ msgid 
 msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: \n
-POT-Creation-Date: 2014-05-28 22:33+0200\n
-PO-Revision-Date: 2014-05-29 08:53+\n
+POT-Creation-Date: 2014-08-31 10:36+0200\n
+PO-Revision-Date: 2014-10-02 17:11+\n
 Last-Translator: runasand runa.sand...@gmail.com\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -43,7 +43,7 @@ msgstr 
 
 #: ../glade/persistencewindow.glade.h:7
 msgid No
-msgstr 
+msgstr Ne
 
 #: ../glade/persistencewindow.glade.h:8
 msgid Passphrase:
@@ -196,7 +196,7 @@ msgid 
 %(stderr)s
 msgstr 
 
-#: ../tailsgreeter/langpanel.py:125 ../tailsgreeter/langpanel.py:152
-#: ../tailsgreeter/langpanel.py:185
+#: ../tailsgreeter/langpanel.py:123 ../tailsgreeter/langpanel.py:150
+#: ../tailsgreeter/langpanel.py:183
 msgid Other...
 msgstr 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb_completed] Update translations for bridgedb_completed

2014-10-02 Thread translation
commit 372b294c8aeecad8ce3a4212ee099961adfb0c58
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:15:10 2014 +

Update translations for bridgedb_completed
---
 eo/LC_MESSAGES/bridgedb.po |  359 
 1 file changed, 359 insertions(+)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
new file mode 100644
index 000..5817fc7
--- /dev/null
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -0,0 +1,359 @@
+# Translations template for BridgeDB.
+# Copyright (C) 2014 'The Tor Project, Inc.'
+# This file is distributed under the same license as the BridgeDB project.
+# 
+# Translators:
+# identity, 2012
+# Rico Chan r...@tutanota.de, 2014
+# trio t...@esperanto.org, 2011
+msgid 
+msgstr 
+Project-Id-Version: The Tor Project\n
+Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
+POT-Creation-Date: 2014-07-26 02:11+\n
+PO-Revision-Date: 2014-10-02 17:11+\n
+Last-Translator: Rico Chan r...@tutanota.de\n
+Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
+MIME-Version: 1.0\n
+Content-Type: text/plain; charset=UTF-8\n
+Content-Transfer-Encoding: 8bit\n
+Generated-By: Babel 0.9.6\n
+Language: eo\n
+Plural-Forms: nplurals=2; plural=(n != 1);\n
+
+#. TRANSLATORS: Please DO NOT translate the following words and/or phrases in
+#. any string (regardless of capitalization and/or punctuation):
+#. BridgeDB
+#. pluggable transport
+#. pluggable transports
+#. obfs2
+#. obfs3
+#. scramblesuit
+#. fteproxy
+#. Tor
+#. Tor Browser
+#: lib/bridgedb/HTTPServer.py:121
+msgid Sorry! Something went wrong with your request.
+msgstr Pardonu! Io ne funkcias pri via peto.
+
+#: lib/bridgedb/strings.py:18
+msgid [This is an automated message; please do not reply.]
+msgstr [Ĉi tiu estas aŭtomate kreita mesaĝo; bonvole ne respondu.]
+
+#: lib/bridgedb/strings.py:20
+msgid Here are your bridges:
+msgstr Jen viaj retpontoj.
+
+#: lib/bridgedb/strings.py:22
+#, python-format
+msgid 
+You have exceeded the rate limit. Please slow down! The minimum time 
between\n
+emails is %s hours. All further emails during this time period will be 
ignored.
+msgstr Vi superis la limiton. Bonvolu malakceli! La minimala tempo inter 
retleteroj estas\n%s horoj. Pliaj retiloj dum tiu tempo estos ignorata.
+
+#: lib/bridgedb/strings.py:25
+msgid 
+COMMANDs: (combine COMMANDs to specify multiple options simultaneously)
+msgstr ORDONOJ: (kombinu ORDONOJN por samtempe specifiki diversaj opciojn).
+
+#. TRANSLATORS: Please DO NOT translate the word BridgeDB.
+#: lib/bridgedb/strings.py:28
+msgid Welcome to BridgeDB!
+msgstr Estu bonvena al BridgeDB!
+
+#. TRANSLATORS: Please DO NOT translate the words transport or TYPE.
+#: lib/bridgedb/strings.py:30
+msgid Currently supported transport TYPEs:
+msgstr Nuntempe subtenata transport TYPEs:
+
+#: lib/bridgedb/strings.py:31
+#, python-format
+msgid Hey, %s!
+msgstr Saluton, %s!
+
+#: lib/bridgedb/strings.py:32
+msgid Hello, friend!
+msgstr Saluton, amiko!
+
+#: lib/bridgedb/strings.py:33 lib/bridgedb/templates/base.html:101
+msgid Public Keys
+msgstr publikaj ŝlosiloj
+
+#. TRANSLATORS: This string will end up saying something like:
+#. This email was generated with rainbows, unicorns, and sparkles
+#. for al...@example.com on Friday, 09 May, 2014 at 18:59:39.
+#: lib/bridgedb/strings.py:37
+#, python-format
+msgid 
+This email was generated with rainbows, unicorns, and sparkles\n
+for %s on %s at %s.
+msgstr Ĉi tiu retletero estas generita kun ĉielarkoj, unikornoj kaj 
steloj\npor %s je %s, %s.
+
+#. TRANSLATORS: Please DO NOT translate BridgeDB.
+#. TRANSLATORS: Please DO NOT translate Pluggable Transports.
+#. TRANSLATORS: Please DO NOT translate Tor.
+#. TRANSLATORS: Please DO NOT translate Tor Network.
+#: lib/bridgedb/strings.py:47
+#, python-format
+msgid 
+BridgeDB can provide bridges with several %stypes of Pluggable 
Transports%s,\n
+which can help obfuscate your connections to the Tor Network, making it 
more\n
+difficult for anyone watching your internet traffic to determine that you 
are\n
+using Tor.\n
+\n
+msgstr BridgeDB povas provizi pontojn/bridges kun diversaj %stypes de 
Pluggable Transports%s,\nkiuj povas helpi sekretigi viajn konektojn al la Tor 
Network kaj malfaciligi provojn kiuj estas destinitaj\nobservi vian 
datumtrafikon kaj vian uzantecon de Tor.\n
+
+#. TRANSLATORS: Please DO NOT translate Pluggable Transports.
+#: lib/bridgedb/strings.py:54
+msgid 
+Some bridges with IPv6 addresses are also available, though some Pluggable\n
+Transports aren't IPv6 compatible.\n
+\n
+msgstr AnkaÅ­ kelkaj retpontoj kun IPv6-adresoj estas disponeblaj, sed iuj 
Pluggable\nTransports ne estas IPv6-kongrua.\n
+
+#. TRANSLATORS: Please DO NOT translate BridgeDB.
+#. TRANSLATORS: The phrase plain-ol'-vanilla means plain, boring,
+#. regular, or unexciting. Like vanilla ice 

[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 8079f87d55a56e67370c34d6789eeff262185f8e
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:15:04 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |   32 
 1 file changed, 16 insertions(+), 16 deletions(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index 813ba46..5817fc7 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 16:43+\n
+PO-Revision-Date: 2014-10-02 17:11+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n
@@ -278,48 +278,48 @@ msgstr kontakto
 #. or for French: Sacrebleu!. :)
 #: lib/bridgedb/templates/bridges.html:66
 msgid Uh oh, spaghettios!
-msgstr 
+msgstr ho ve, ho ve!
 
 #: lib/bridgedb/templates/bridges.html:72
 msgid There currently aren't any bridges available...
-msgstr 
+msgstr Nuntempe ne ekzistas retpontojn.
 
 #: lib/bridgedb/templates/bridges.html:73
 #, python-format
 msgid 
  Perhaps you should try %s going back %s and choosing a different bridge 
 type!
-msgstr 
+msgstr Vi eble davas provi %s reiri %s kaj selekti alian retpontospeco.
 
 #: lib/bridgedb/templates/index.html:11
 #, python-format
 msgid Step %s1%s
-msgstr 
+msgstr paŝo %s1%s
 
 #: lib/bridgedb/templates/index.html:13
 #, python-format
 msgid Download %s Tor Browser %s
-msgstr 
+msgstr elŝuti %s Tor-retumilo %s
 
 #: lib/bridgedb/templates/index.html:25
 #, python-format
 msgid Step %s2%s
-msgstr 
+msgstr paŝo %s2%s
 
 #: lib/bridgedb/templates/index.html:27
 #, python-format
 msgid Get %s bridges %s
-msgstr 
+msgstr ekhavi %s retpotojn %s
 
 #: lib/bridgedb/templates/index.html:36
 #, python-format
 msgid Step %s3%s
-msgstr 
+msgstr paŝo %s3%s
 
 #: lib/bridgedb/templates/index.html:38
 #, python-format
 msgid Now %s add the bridges to Tor Browser %s
-msgstr 
+msgstr Nun %s aldonu la retpontojn al la Tor-retumilo %s
 
 #. TRANSLATORS: Please make sure the '%s' surrounding single letters at the
 #. beginning of words are present in your final translation. Thanks!
@@ -328,19 +328,19 @@ msgstr 
 #: lib/bridgedb/templates/options.html:38
 #, python-format
 msgid %sJ%sust give me bridges!
-msgstr 
+msgstr %sT%suj donu retpontojn al mi!
 
 #: lib/bridgedb/templates/options.html:52
 msgid Advanced Options
-msgstr 
+msgstr detalaj opcioj
 
 #: lib/bridgedb/templates/options.html:88
 msgid No
-msgstr 
+msgstr Ne
 
 #: lib/bridgedb/templates/options.html:89
 msgid none
-msgstr 
+msgstr neniom/neniu
 
 #. TRANSLATORS: Please make sure the '%s' surrounding single letters at the
 #. beginning of words are present in your final translation. Thanks!
@@ -348,7 +348,7 @@ msgstr 
 #: lib/bridgedb/templates/options.html:130
 #, python-format
 msgid %sY%ses!
-msgstr 
+msgstr %sJ%ses!
 
 #. TRANSLATORS: Please make sure the '%s' surrounding single letters at the
 #. beginning of words are present in your final translation. Thanks!
@@ -356,4 +356,4 @@ msgstr 
 #: lib/bridgedb/templates/options.html:154
 #, python-format
 msgid %sG%set Bridges
-msgstr 
+msgstr %sE%skhavi Bridges

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-launcher-network-settings] Update translations for tor-launcher-network-settings

2014-10-02 Thread translation
commit bf0a65bc4a9f452704293dbfbc7e49c1caaeca40
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:16:09 2014 +

Update translations for tor-launcher-network-settings
---
 eo/network-settings.dtd |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/eo/network-settings.dtd b/eo/network-settings.dtd
index 5f32b65..4f96a94 100644
--- a/eo/network-settings.dtd
+++ b/eo/network-settings.dtd
@@ -5,7 +5,7 @@
 !ENTITY torsettings.prompt Before you connect to the Tor network, you need 
to provide information about this computer's Internet connection.
 
 !ENTITY torSettings.yes Yes
-!ENTITY torSettings.no No
+!ENTITY torSettings.no Ne
 
 !ENTITY torSettings.firstQuestion Which of the following best describes your 
situation?
 !ENTITY torSettings.configurePrompt1 This computer's Internet connection is 
censored or proxied.

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb_completed] Update translations for bridgedb_completed

2014-10-02 Thread translation
commit cf9010f1b570b0e38845508ed3c79233b3f6beba
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:45:07 2014 +

Update translations for bridgedb_completed
---
 eo/LC_MESSAGES/bridgedb.po |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index 5817fc7..b86281a 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 17:11+\n
+PO-Revision-Date: 2014-10-02 17:20+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit 633d214a78e25d7338c7d286cb10f5f2c797b866
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:45:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/eo/LC_MESSAGES/bridgedb.po b/eo/LC_MESSAGES/bridgedb.po
index 5817fc7..b86281a 100644
--- a/eo/LC_MESSAGES/bridgedb.po
+++ b/eo/LC_MESSAGES/bridgedb.po
@@ -11,7 +11,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: 
'https://trac.torproject.org/projects/tor/newticket?component=BridgeDBkeywords=bridgedb-reported,msgidcc=isis,sysrqbowner=isis'\n
 POT-Creation-Date: 2014-07-26 02:11+\n
-PO-Revision-Date: 2014-10-02 17:11+\n
+PO-Revision-Date: 2014-10-02 17:20+\n
 Last-Translator: Rico Chan r...@tutanota.de\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-greeter] Update translations for tails-greeter

2014-10-02 Thread translation
commit fe6b2d878de6fa43e12dec458f9f20fd2473fdcd
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 17:45:35 2014 +

Update translations for tails-greeter
---
 eo/eo.po |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/eo/eo.po b/eo/eo.po
index 5abf014..0e131b5 100644
--- a/eo/eo.po
+++ b/eo/eo.po
@@ -8,7 +8,7 @@ msgstr 
 Project-Id-Version: The Tor Project\n
 Report-Msgid-Bugs-To: \n
 POT-Creation-Date: 2014-08-31 10:36+0200\n
-PO-Revision-Date: 2014-10-02 17:11+\n
+PO-Revision-Date: 2014-10-02 17:20+\n
 Last-Translator: runasand runa.sand...@gmail.com\n
 Language-Team: Esperanto 
(http://www.transifex.com/projects/p/torproject/language/eo/)\n
 MIME-Version: 1.0\n

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [flashproxy/master] Remove a trailing comma from a list.

2014-10-02 Thread dcf
commit 9e0977834fd951cdcceeca6acbcba967fb9a3ca7
Author: David Fifield da...@bamsoftware.com
Date:   Thu Oct 2 10:57:15 2014 -0700

Remove a trailing comma from a list.
---
 proxy/flashproxy.js |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/proxy/flashproxy.js b/proxy/flashproxy.js
index f7d1e35..15c6cf3 100644
--- a/proxy/flashproxy.js
+++ b/proxy/flashproxy.js
@@ -1081,7 +1081,7 @@ function flashproxy_should_disable() {
 var UA_LIST = [
 /\bmobile\b/i,
 /\bandroid\b/i,
-/\bopera mobi\b/i,
+/\bopera mobi\b/i
 ];
 
 for (var i = 0; i  UA_LIST.length; i++) {

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [flashproxy/master] Match TBB User-Agent for 31ESR.

2014-10-02 Thread dcf
commit 8290f77bd1591b3ea363018ca220529bba0f2526
Author: David Fifield da...@bamsoftware.com
Date:   Thu Oct 2 10:50:57 2014 -0700

Match TBB User-Agent for 31ESR.

https://trac.torproject.org/projects/tor/ticket/13165
---
 proxy/flashproxy.js |1 +
 1 file changed, 1 insertion(+)

diff --git a/proxy/flashproxy.js b/proxy/flashproxy.js
index e5f366d..f7d1e35 100644
--- a/proxy/flashproxy.js
+++ b/proxy/flashproxy.js
@@ -1052,6 +1052,7 @@ var TBB_UAS = [
 Mozilla/5.0 (Windows NT 6.1; rv:10.0) Gecko/20100101 Firefox/10.0,
 Mozilla/5.0 (Windows NT 6.1; rv:17.0) Gecko/20100101 Firefox/17.0,
 Mozilla/5.0 (Windows NT 6.1; rv:24.0) Gecko/20100101 Firefox/24.0,
+Mozilla/5.0 (Windows NT 6.1; rv:31.0) Gecko/20100101 Firefox/31.0
 ];
 function is_likely_tor_browser() {
 return TBB_UAS.indexOf(window.navigator.userAgent)  -1



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torcheck_completed] Update translations for torcheck_completed

2014-10-02 Thread translation
commit 7505249a9d8850dd2c68b6b939f701e93e67df22
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 18:15:16 2014 +

Update translations for torcheck_completed
---
 es/torcheck.po |7 ---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/es/torcheck.po b/es/torcheck.po
index de12063..197654f 100644
--- a/es/torcheck.po
+++ b/es/torcheck.po
@@ -6,6 +6,7 @@
 # toypurina biole...@riseup.net, 2014
 # her_tor_es_ar cvma...@gmail.com, 2014
 # Dani_RU danio...@hotmail.com, 2014
+# David Martinez Gisbert desarrollo.davidmgisb...@gmail.com, 2014
 # gaspa gaspa...@hotmail.com, 2014
 # cronayu itacron...@hotmail.com, 2012
 # Noel Torres env...@rolamasao.org, 2013
@@ -20,8 +21,8 @@ msgid 
 msgstr 
 Project-Id-Version: The Tor Project\n
 POT-Creation-Date: 2012-02-16 20:28+PDT\n
-PO-Revision-Date: 2014-08-18 17:10+\n
-Last-Translator: toypurina biole...@riseup.net\n
+PO-Revision-Date: 2014-10-02 18:01+\n
+Last-Translator: David Martinez Gisbert 
desarrollo.davidmgisb...@gmail.com\n
 Language-Team: Spanish 
(http://www.transifex.com/projects/p/torproject/language/es/)\n
 MIME-Version: 1.0\n
 Content-Type: text/plain; charset=UTF-8\n
@@ -31,7 +32,7 @@ msgstr 
 Plural-Forms: nplurals=2; plural=(n != 1);\n
 
 msgid Congratulations. This browser is configured to use Tor.
-msgstr Felicitaciones. Este navegador está configurado para utilizar Tor.
+msgstr Felicidades. Este navegador está configurado para utilizar Tor.
 
 msgid 
 Please refer to the a href=\https://www.torproject.org/\;Tor website/a 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/torcheck] Update translations for torcheck

2014-10-02 Thread translation
commit efc4e804bacb32630cfdc647fc14d56991363c72
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 18:15:12 2014 +

Update translations for torcheck
---
 es/torcheck.po |7 ---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/es/torcheck.po b/es/torcheck.po
index de12063..197654f 100644
--- a/es/torcheck.po
+++ b/es/torcheck.po
@@ -6,6 +6,7 @@
 # toypurina biole...@riseup.net, 2014
 # her_tor_es_ar cvma...@gmail.com, 2014
 # Dani_RU danio...@hotmail.com, 2014
+# David Martinez Gisbert desarrollo.davidmgisb...@gmail.com, 2014
 # gaspa gaspa...@hotmail.com, 2014
 # cronayu itacron...@hotmail.com, 2012
 # Noel Torres env...@rolamasao.org, 2013
@@ -20,8 +21,8 @@ msgid 
 msgstr 
 Project-Id-Version: The Tor Project\n
 POT-Creation-Date: 2012-02-16 20:28+PDT\n
-PO-Revision-Date: 2014-08-18 17:10+\n
-Last-Translator: toypurina biole...@riseup.net\n
+PO-Revision-Date: 2014-10-02 18:01+\n
+Last-Translator: David Martinez Gisbert 
desarrollo.davidmgisb...@gmail.com\n
 Language-Team: Spanish 
(http://www.transifex.com/projects/p/torproject/language/es/)\n
 MIME-Version: 1.0\n
 Content-Type: text/plain; charset=UTF-8\n
@@ -31,7 +32,7 @@ msgstr 
 Plural-Forms: nplurals=2; plural=(n != 1);\n
 
 msgid Congratulations. This browser is configured to use Tor.
-msgstr Felicitaciones. Este navegador está configurado para utilizar Tor.
+msgstr Felicidades. Este navegador está configurado para utilizar Tor.
 
 msgid 
 Please refer to the a href=\https://www.torproject.org/\;Tor website/a 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits
diff --git a/lib/trunnel/Grammar.py b/lib/trunnel/Grammar.py
index c5c20e5..0de7fa7 100644
--- a/lib/trunnel/Grammar.py
+++ b/lib/trunnel/Grammar.py
@@ -11,6 +11,8 @@
 
 
 import trunnel.spark
+pattern = trunnel.spark.pattern
+rule = trunnel.spark.rule
 
 #
 #
@@ -98,9 +100,11 @@ class Lexer(trunnel.spark.GenericScanner, object):
 Scanner class based on trunnel.spark.GenericScanner.  Its job is to turn
a string into a list of Token.
 
-   Note that spark does most of the work for us here: under the hood,
-   it builds a big regex out of all the docstrings for the t_* methods,
-   and uses that to do the scanning and decide which function to invoke.
+   Note that spark does most of the work for us here: under the
+   hood, it builds a big regex out of all the @pattern decorations
+   for the t_* methods, and uses that to do the scanning and
+   decide which function to invoke.
+
 
 
 def tokenize(self, input):
@@ -109,12 +113,12 @@ class Lexer(trunnel.spark.GenericScanner, object):
 trunnel.spark.GenericScanner.tokenize(self, input)
 return self.rv
 
+@pattern(r(?:[;{}\[\]\-=,:]|\.\.\.|\.\.|\.))
 def t_punctuation(self, s):
-r(?:[;{}\[\]\-=,:]|\.\.\.|\.\.|\.)
 self.rv.append(Token(s, self.lineno))
 
+@pattern(r[a-zA-Z_][a-zA-Z_0-9]*)
 def t_id(self, s):
-r[a-zA-Z_][a-zA-Z_0-9]*
 if s in KEYWORDS:
 self.rv.append(Token(s, self.lineno))
 elif s.isupper():
@@ -122,33 +126,33 @@ class Lexer(trunnel.spark.GenericScanner, object):
 else:
 self.rv.append(Identifier(s, self.lineno))
 
+@pattern(r0x[0-9a-fA-F]+ | [0-9]+ )
 def t_int(self, s):
-r0x[0-9a-fA-F]+ | [0-9]+ 
 self.rv.append(IntLiteral(s, self.lineno))
 
+@pattern(r[ \t]+)
 def t_space(self, s):
-r[ \t]+
 pass
 
+@pattern(r\/\/.*)
 def t_comment1(self, s):
-r\/\/.*
 pass
 
+@pattern(r'/\*\*(?:[^\*]|\*+[^*/])*\*/')
 def t_annotation(self, s):
-r'/\*\*(?:[^\*]|\*+[^*/])*\*/'
 self.rv.append(Annotation(s, self.lineno))
 self.lineno += (s.count(\n))
 
+@pattern(r'/\*[^\*](?:[^\*]|\*+[^*/])*\*/')
 def t_comment2(self, s):
-r'/\*[^\*](?:[^\*]|\*+[^*/])*\*/'
 self.lineno += (s.count(\n))
 
+@pattern(r\n)
 def t_newline(self, s):
-r\n
 self.lineno += 1
 
+@pattern(r.)
 def t_default(self, s):
-r.
 raise ValueError(unmatched input: %r on line %r % (s, self.lineno))
 
 #
@@ -595,9 +599,10 @@ class Parser(trunnel.spark.GenericParser, object):
(trunnel.spark.GenericParser is an Earley parse, with O(n^3) worst-case
performance, but we don't care.)
 
-   Each p_* method represents a single grammar rule in its docstring;
-   it gets invoked in order to reduce the items listed to the
-   lhs of the rule.
+   Each p_* method represents a single grammar rule in its @rule
+   decoration: it gets invoked in order to reduce the items listed
+   to the lhs of the rule.
+
 
 #
 # lingering_structs -- a list of StructDecl for structs declared
@@ -615,271 +620,275 @@ class Parser(trunnel.spark.GenericParser, object):
 def error(self, token):
 raise SyntaxError(%s at %s % (token, token.lineno))
 
+@rule( File ::= Declarations )
 def p_File_0(self, info):
- File ::= Declarations 
 d = info[0]
 d.extend(self.lingering_structs)
 return File(d)
 
+@rule( Declarations ::= Declaration )
 def p_Declarations_1(self, info):
- Declarations ::= Declaration 
 d = info[0]
 return [d]
 
+@rule( Declarations ::= Declarations Declaration )
 def p_Declarations_2(self, info):
- Declarations ::= Declarations Declaration 
 ds, d = info
 ds.append(d)
 return ds
 
+@rule( Declaration ::= OptAnnotation ConstDecl )
 def p_Decl_1(self, info):
- Declaration ::= OptAnnotation ConstDecl 
+
 a, d = info
 if a:
 d.annotation = str(a)
 return d
 
+@rule( Declaration ::= OptAnnotation StructDecl OptSemi )
 def p_Decl_2(self, info):
- Declaration ::= OptAnnotation StructDecl OptSemi 
 a, d, _1 = info
 if a:
  

[tor-commits] [translation/bridgedb] Update translations for bridgedb

2014-10-02 Thread translation
commit bf829b8a5e86f738ea303fdbffe10a2b4036dbd7
Author: Translation commit bot translat...@torproject.org
Date:   Thu Oct 2 14:15:03 2014 +

Update translations for bridgedb
---
 eo/LC_MESSAGES/bridgedb.po |   12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)
